/*****************************************************************************
 * Copyright (c) 2019, Nations Technologies Inc.
 *
 * All rights reserved.
 * ****************************************************************************
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Nations' name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY NATIONS "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL NATIONS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ****************************************************************************/
 
/**
*\*\file main.c
*\*\author Nations
*\*\version v1.0.0
*\*\copyright Copyright (c) 2019, Nations Technologies Inc. All rights reserved.
**/

#include <stdio.h>
#include "main.h"
#include "log.h"
#include "bsp_delay.h"
#include "st7735.h"


#define VOLTAGE_FACTOR       1.0F                 // 实际电压与表显电压的比值
#define CURRENT_FACTOR       1.0F                 // 实际电流与表显电流的比值

#define VOLTAGE_ADC_CHANNEL  ADC_Channel_02_PA1   // 电压采样通道编号
#define CURRENT_ADC_CHANNEL  ADC_Channel_03_PA2   // 电流采样通道编号

#define KEY_PORT	GPIOB
#define KEY_ENTER	GPIO_PIN_5
#define KEY_NEXT	GPIO_PIN_5//GPIO_PIN_6
#define KEY_PREV	GPIO_PIN_7


static void BSP_ADC_Init()
{
	// 启用外设时钟
	RCC_AHB_Peripheral_Clock_Enable(RCC_AHB_PERIPH_GPIOA | RCC_AHB_PERIPH_ADC);
	ADC_Clock_Mode_Config(ADC_CKMOD_AHB, RCC_ADCHCLK_DIV16);
	RCC_ADC_1M_Clock_Config(RCC_ADC1MCLK_SRC_HSI, RCC_ADC1MCLK_DIV8); // selsect HSE as RCC ADC1M CLK Source

	GPIO_InitType GPIO_InitStructure;

	// 将ADC相关引脚设置工作模式设置为模拟模式
	GPIO_Structure_Initialize(&GPIO_InitStructure);
	GPIO_InitStructure.Pin = GPIO_PIN_1 | GPIO_PIN_2;
	GPIO_InitStructure.GPIO_Mode = GPIO_MODE_ANALOG;
	GPIO_Peripheral_Initialize(GPIOA, &GPIO_InitStructure);

	ADC_InitType ADC_InitStructure;

	// 配置ADC参数
	ADC_InitStructure.MultiChEn = DISABLE;
	ADC_InitStructure.ContinueConvEn = DISABLE;
	ADC_InitStructure.ExtTrigSelect = ADC_EXT_TRIGCONV_REGULAR_SWSTRRCH;
	ADC_InitStructure.DatAlign = ADC_DAT_ALIGN_R;
	ADC_InitStructure.ChsNumber = ADC_REGULAR_LEN_1;
	ADC_Initializes(&ADC_InitStructure);

	// 启动ADC
	ADC_ON();
	// 等待ADC就绪
	while (ADC_Flag_Status_Get(ADC_RD_FLAG, ADC_FLAG_AWDG, ADC_FLAG_RDY) == RESET)
	{
		__NOP();
	}

	// 启动ADC自校准
	ADC_Calibration_Operation(ADC_CALIBRATION_ENABLE);
	// 等待ADC自校准完成
	while (ADC_Calibration_Operation(ADC_CALIBRATION_STS) == SET)
	{
		__NOP();
	}
}

static uint16_t BSP_ADC_GetData(uint8_t ADC_Channel)
{
	// 配置采样参数
	ADC_Channel_Sample_Time_Config(ADC_Channel, ADC_SAMP_TIME_55CYCLES5);
	ADC_Regular_Sequence_Conversion_Number_Config(ADC_Channel, ADC_REGULAR_NUMBER_1);

	// 启动ADC转换
	ADC_Regular_Channels_Software_Conversion_Operation(ADC_EXTRTRIG_SWSTRRCH_ENABLE);
	// 等待ADC转换完成
	while (ADC_Flag_Status_Get(ADC_RUN_FLAG, ADC_FLAG_ENDC, ADC_FLAG_RDY) == 0)
	{
		__NOP();
	}
	ADC_Flag_Status_Clear(ADC_FLAG_ENDC);
	ADC_Flag_Status_Clear(ADC_FLAG_STR);
	
	// 获取ADC采样值
	return ADC_Regular_Group_Conversion_Data_Get();
}

static void InputInit()
{
	RCC_AHB_Peripheral_Clock_Enable(RCC_AHB_PERIPH_GPIOB);

	GPIO_InitType GPIO_InitStructure;
	GPIO_Structure_Initialize(&GPIO_InitStructure);
	GPIO_InitStructure.Pin       = KEY_ENTER | KEY_NEXT | KEY_PREV;
	GPIO_InitStructure.GPIO_Mode = GPIO_MODE_INPUT;
	GPIO_InitStructure.GPIO_Pull = GPIO_PULL_DOWN;
	GPIO_Peripheral_Initialize(KEY_PORT, &GPIO_InitStructure);
}


static void DrawChart(uint16_t volBuf[], uint16_t curBuf[], uint16_t cv, uint16_t cc, uint16_t cp)
{
#define iy(y) (ST77XX_HEIGHT - 1 - (y))
#define vy(v) iy(v * 4 / 1000 + 80)
#define cy(c) iy(c * 13 / 1000 + 40)
#define py(p) iy(p * 2 / 1000 + 0)
	ST77XX_DrawLine(0, iy(40 - 1), ST77XX_WIDTH, iy(40 - 1), 0b0001000010000100);
	ST77XX_DrawLine(0, iy(80 - 1), ST77XX_WIDTH, iy(80 - 1), 0b0001000010000100);
	for (int x = 0; x < ST77XX_WIDTH - 1; x++)
	{
		if (volBuf[x + 1] == 0) return;
		uint16_t power = volBuf[x] * curBuf[x] / 1000;
		uint16_t power1 = volBuf[x + 1] * curBuf[x + 1] / 1000;
		// ST77XX_DrawPoint(x, ST77XX_HEIGHT - 1 - volBuf[x] * 10 / 1000, cv);
		// ST77XX_DrawPoint(x, ST77XX_HEIGHT - 1 - curBuf[x] * 30 / 1000, cc);
		// ST77XX_DrawPoint(x, ST77XX_HEIGHT - 1 - power     *  5 / 1000, cp);
		ST77XX_DrawLine(x, vy(volBuf[x]), x + 1, vy(volBuf[x + 1]), cv);
		ST77XX_DrawLine(x, cy(curBuf[x]), x + 1, cy(curBuf[x + 1]), cc);
		ST77XX_DrawLine(x, py(power), x + 1, py(power1), cp);
	}
}


/**
 *\*\name   main.
 *\*\fun    main function.
 *\*\param  none.
 *\*\return none.
**/
int main(void)
{
    /* USART Init */
    log_init();
    
    printf("USB Meter Start\r\n");

    printf("ST7735_Init\r\n");
	ST7735_Init();
    printf("ST7735_Init end\r\n");

	ST77XX_Clear(ST77XX_WHITE);
	ST77XX_DrawLogo(0, 34);

	BSP_ADC_Init();

	InputInit();

	SysTick_Delay_Ms(1000);
	ST77XX_Clear(ST77XX_WHITE);


	// 定义ADC的1LSB与实际电压电流的比值
	const float volFactor = 7.997887F * VOLTAGE_FACTOR;
	const float curFactor = 2.099137F * CURRENT_FACTOR;
	// 定义电压和电流的ADC采样值
	uint32_t volRaw = 0, curRaw = 0;
	// 定义电压和电流值，单位mV/mA
	uint16_t voltage = 0, current = 0;
	// 定义功率值，单位毫瓦
	uint32_t power = 0;

	int keyPrevState = GPIO_Input_Pin_Data_Get(KEY_PORT, KEY_PREV);
	int keyNextState = GPIO_Input_Pin_Data_Get(KEY_PORT, KEY_NEXT);
	uint16_t volBuf[ST77XX_WIDTH] = {0};
	uint16_t curBuf[ST77XX_WIDTH] = {0};
	int bufIndex = -1;
	char strbuf[256];
	int showMode = 0;
	while (1)
	{
		// 采样电压和电流的ADC值，16倍过采样
		volRaw = 0;
		curRaw = 0;
		for (int i = 0; i < 16; i++)
		{
			volRaw += BSP_ADC_GetData(VOLTAGE_ADC_CHANNEL);
			curRaw += BSP_ADC_GetData(CURRENT_ADC_CHANNEL);
			SysTick_Delay_Ms(10);
		}
		volRaw >>= 4;
		curRaw >>= 4;

		// 计算实际的电压、电流和功率
		voltage = volRaw * volFactor;
		current = curRaw * curFactor;
		power = current * voltage / 1000;

		if (++bufIndex >= ST77XX_WIDTH)
		{
			bufIndex = 0;
			ST77XX_Clear(ST77XX_WHITE);
			for (int i = 0; i < ST77XX_WIDTH; i++)
			{
				volBuf[i] = 0;
			}
			// bufIndex = ST77XX_WIDTH - 1;
			// if (showMode == 1)
			// {
			// 	DrawChart(volBuf, curBuf, ST77XX_WHITE, ST77XX_WHITE, ST77XX_WHITE);
			// }
			// for (int i = 0; i < ST77XX_WIDTH - 1; i++)
			// {
			// 	volBuf[i] = volBuf[i + 1];
			// 	curBuf[i] = curBuf[i + 1];
			// }
		}
		volBuf[bufIndex] = voltage;
		curBuf[bufIndex] = current;

		int keyState = GPIO_Input_Pin_Data_Get(KEY_PORT, KEY_PREV);
		if (keyState != keyPrevState)
		{
			keyPrevState = keyState;
			if (keyState == PIN_SET) // prev key down
			{
				showMode = (showMode + 3 - 1) % 3;
				printf("showMode %d\r\n", showMode);
				ST77XX_Clear(ST77XX_WHITE);
			}
		}
		keyState = GPIO_Input_Pin_Data_Get(KEY_PORT, KEY_NEXT);
		if (keyState != keyNextState)
		{
			keyNextState = keyState;
			if (keyState == PIN_SET) // next key down
			{
				showMode = (showMode + 1) % 3;
				printf("showMode %d\r\n", showMode);
				ST77XX_Clear(ST77XX_WHITE);
			}
		}

		if (showMode == 0)
		{
			int y = (ST77XX_HEIGHT - 32 * 3) / 2;
			sprintf(strbuf, "%u.%02uV", voltage / 1000, (voltage % 1000) / 10);
			ST77XX_DrawString(0, y, strbuf, &Font_16x32, ST77XX_RED, ST77XX_WHITE);

			sprintf(strbuf, "%u.%02uA", current / 1000, (current % 1000) / 10);
			ST77XX_DrawString(0, y + 32, strbuf, &Font_16x32, ST77XX_GREEN, ST77XX_WHITE);

			sprintf(strbuf, "%u.%02uW", power / 1000, (power % 1000) / 10);
			ST77XX_DrawString(0, y + 64, strbuf, &Font_16x32, ST77XX_BLUE, ST77XX_WHITE);
		}
		else if (showMode == 1)
		{
			FontDef_t* font = &Font_6x12;
			sprintf(strbuf, "%u.%02uV", voltage / 1000, (voltage % 1000) / 10);
			ST77XX_DrawString(0, 0, strbuf, font, ST77XX_RED, ST77XX_WHITE);

			sprintf(strbuf, "%u.%02uA", current / 1000, (current % 1000) / 10);
			ST77XX_DrawString(0, iy(80 - 2), strbuf, font, ST77XX_GREEN, ST77XX_WHITE);

			sprintf(strbuf, "%u.%02uW", power / 1000, (power % 1000) / 10);
			ST77XX_DrawString(0, iy(40 - 2), strbuf, font, ST77XX_BLUE, ST77XX_WHITE);
			DrawChart(volBuf, curBuf, ST77XX_RED, ST77XX_GREEN, ST77XX_BLUE);
		}
		else if (showMode == 2)
		{
			ST77XX_DrawLogo(0, 34);
		}

	}

}


