/******************************************************************************
** 
 * \file        st77xx.c
 * \author      IOsetting | iosetting@outlook.com
 * \date        
 * \brief       Library of ST77XX TFT LCD on W806
 * \note        
 * \version     v0.1
 * \ingroup     demo
 * \remarks     test-board: HLK-W806-KIT-V1.0
 *              
 *              B10   -> RES, RESET
 *              B11   -> DC, CD
 *              B14   -> CS, Chip Select
 *              B15   -> SCK, SCL, CLK, Clock
 *              B16   -> BL, Back Light
 *              B17   -> MOSI, SDA
 *              GND   -> GND
 *              3.3V  -> VCC
 * 
 *              ST77XX_HARDWARE_SPI - 0: Software SPI, 1: Hardware SPI
 * 
******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "st77xx.h"
#include "bsp_delay.h"


#define HAL_MAX_DELAY 0xffff


static uint8_t st77xx_buf[ST77XX_BUF_SIZE];
static uint16_t st77xx_buf_pt = 0;


#if ST77XX_HARDWARE_SPI
typedef enum
{
    FAILED = 0,
    PASSED = !FAILED
} Status, TestStatus;

// #define HARDWARE_NSS

#define SPI_MASTER                SPI1
#define SPI_MASTER_PERIPH         RCC_APB2_PERIPH_SPI1
#define SPI_MASTER_PERIPH_GPIO    RCC_AHB_PERIPH_GPIOA
#define SPI_MASTER_GPIO           GPIOA
#define SPI_MASTER_GPIO_ALTERNATE GPIO_AF1_SPI1
#define SPI_MASTER_MOSI_PIN       ST77XX_MOSI_PIN
#define SPI_MASTER_CLK_PIN        ST77XX_SCK_PIN
#define SPI_MASTER_NSS_PIN        ST77XX_CS_PIN

static SPI_InitType SPI_InitStructure;

/**
*\*\name    RCC_Configuration.
*\*\fun     Configures the different system clocks.
*\*\param   none
*\*\return  none
**/
static void RCC_Configuration(void)
{
    /* PCLK2 = HCLK/2 */
    // RCC_Pclk2_Config(RCC_HCLK_DIV2);

    /* Enable peripheral clocks --------------------------------------------------*/
    /* spi clock enable */
    RCC_APB2_Peripheral_Clock_Enable(SPI_MASTER_PERIPH);

    /* GPIO Periph clock enable */
    RCC_AHB_Peripheral_Clock_Enable(SPI_MASTER_PERIPH_GPIO);
}

/**
*\*\name    GPIO_Configuration.
*\*\fun     Configures the different GPIO ports.
*\*\param   none
*\*\return  none
**/
static void SPI_GPIO_Configuration(void)
{                              
    GPIO_InitType GPIO_InitStructure;

    GPIO_Structure_Initialize(&GPIO_InitStructure);
    /* Configure master pins: SCK, MISO and MOSI ---------------------------------*/
    /* Confugure SCK and MOSI pins as Alternate Function Push Pull */
    GPIO_InitStructure.Pin        = SPI_MASTER_MOSI_PIN | SPI_MASTER_CLK_PIN | SPI_MASTER_NSS_PIN;
    GPIO_InitStructure.GPIO_Mode  = GPIO_MODE_AF_PP;
    GPIO_InitStructure.GPIO_Slew_Rate = GPIO_SLEW_RATE_FAST;
    GPIO_InitStructure.GPIO_Alternate = SPI_MASTER_GPIO_ALTERNATE;
    GPIO_Peripheral_Initialize(SPI_MASTER_GPIO, &GPIO_InitStructure);
}

static void initSpi()
{
    RCC_Configuration();
    SPI_GPIO_Configuration();
    SPI_I2S_Reset(SPI_MASTER);
    
    /* SPI_MASTER configuration --------------------------------------------------*/
    SPI_Initializes_Structure(&SPI_InitStructure);
    SPI_InitStructure.DataDirection = SPI_DIR_DOUBLELINE_FULLDUPLEX;
    SPI_InitStructure.SpiMode       = SPI_MODE_MASTER;
    SPI_InitStructure.DataLen       = SPI_DATA_SIZE_8BITS;
    SPI_InitStructure.CLKPOL        = SPI_CLKPOL_HIGH;
    SPI_InitStructure.CLKPHA        = SPI_CLKPHA_SECOND_EDGE;
    SPI_InitStructure.NSS           = SPI_NSS_SOFT;
    /* It is recommended that the SPI master mode of the C version chips should not exceed 18MHz */
    SPI_InitStructure.BaudRatePres  = SPI_BR_PRESCALER_2;
    SPI_InitStructure.FirstBit      = SPI_FB_MSB;
    SPI_InitStructure.CRCPoly       = 7;
    SPI_Initializes(SPI_MASTER, &SPI_InitStructure);
    SPI_Set_Nss_Level(SPI_MASTER, SPI_NSS_HIGH);
    
    /* Enable SPI_MASTER CRC calculation */
    // SPI_CRC_Enable(SPI_MASTER);

#ifdef HARDWARE_NSS
        SPI_NSS_Config(SPI_MASTER, SPI_NSS_HARD);
        SPI_SS_Output_Enable(SPI_MASTER);
#endif

    /* Enable SPI_MASTER */
    SPI_ON(SPI_MASTER);
}
#endif

/**
 *\*\param  GPIOx :
 *\*\          - GPIOA
 *\*\          - GPIOB
 *\*\          - GPIOC
 *\*\          - GPIOD
 *\*\param  pin :
 *\*\          - GPIO_PIN_0
 *\*\          - GPIO_PIN_1
 *\*\          - GPIO_PIN_2
 *\*\          - GPIO_PIN_3
 *\*\          - GPIO_PIN_4
 *\*\          - GPIO_PIN_5
 *\*\          - GPIO_PIN_6
 *\*\          - GPIO_PIN_7
 *\*\          - GPIO_PIN_8
 *\*\          - GPIO_PIN_9
 *\*\          - GPIO_PIN_10
 *\*\          - GPIO_PIN_11
 *\*\          - GPIO_PIN_12
 *\*\          - GPIO_PIN_13
 *\*\          - GPIO_PIN_14
 *\*\          - GPIO_PIN_15
 *\*\param  AHB_periph :
 *\*\          - RCC_AHB_PERIPH_GPIOA
 *\*\          - RCC_AHB_PERIPH_GPIOB
 *\*\          - RCC_AHB_PERIPH_GPIOC
 *\*\          - RCC_AHB_PERIPH_GPIOD
**/
static void GPIO_Initialize(GPIO_Module* GPIOx, uint16_t pin, uint32_t AHB_periph)
{
	/* Define a structure of type GPIO_InitType */
	GPIO_InitType GPIO_InitStructure;
	
	/* Enable LED related GPIO peripheral clock */
	RCC_AHB_Peripheral_Clock_Enable(AHB_periph);
	
	/* Assign default value to GPIO_InitStructure structure */
	GPIO_Structure_Initialize(&GPIO_InitStructure);
	
	/* Select the GPIO pin to control */
	GPIO_InitStructure.Pin          = pin;
	/* Set pin mode to general push-pull output */
	GPIO_InitStructure.GPIO_Mode    = GPIO_MODE_OUT_PP;
	/* Set the pin drive current to 4MA*/
	GPIO_InitStructure.GPIO_Current = GPIO_DS_4MA;
	/* Initialize GPIO */
	GPIO_Peripheral_Initialize(GPIOx, &GPIO_InitStructure);
}

void ST77XX_Init(void)
{
    uint16_t pina = 0, pinb = 0;

#if !ST77XX_HARDWARE_SPI
    printf("init gpio cs sck mosi\n");
    pina = ST77XX_CS_PIN
         | ST77XX_SCK_PIN
         | ST77XX_MOSI_PIN
         | ST77XX_RES_PIN;
    pinb = ST77XX_DC_PIN
         | ST77XX_BL_PIN;
#else
    printf("init spi\n");
    initSpi();
    pina = ST77XX_RES_PIN;
    pinb = ST77XX_DC_PIN
         | ST77XX_BL_PIN;
#endif

    GPIO_Initialize(GPIOA, pina, RCC_AHB_PERIPH_GPIOA);
    GPIO_Initialize(GPIOB, pinb, RCC_AHB_PERIPH_GPIOB);
}


void ST77XX_Reset(void)
{
    ST77XX_RESET_LOW;
    SysTick_Delay_Ms(10);
    ST77XX_RESET_HIGH;
}

static void ST77XX_TransmitByte(uint8_t dat)
{
#if ST77XX_HARDWARE_SPI
    // ST77XX_CS_LOW;
    /* Wait for SPI_MASTER Tx buffer empty */
    while (SPI_I2S_Flag_Status_Get(SPI_MASTER, SPI_I2S_FLAG_TE) == RESET)
        ;
    /* Send SPI_MASTER data */
    SPI_I2S_Data_Transmit(SPI_MASTER, dat);
    while (SPI_I2S_Flag_Status_Get(SPI_MASTER, SPI_I2S_FLAG_RNE) == RESET)
        ;
    SPI_I2S_Data_Get(SPI_MASTER);
    // ST77XX_CS_HIGH;
#else
    uint8_t i;
    ST77XX_CS_LOW;
    for (i = 0; i < 8; i++)
    {
        ST77XX_SCK_LOW;
        if (dat & 0x80)
        {
            ST77XX_MOSI_HIGH;
        }
        else
        {
            ST77XX_MOSI_LOW;
        }
        ST77XX_SCK_HIGH;
        dat <<= 1;
    }
    ST77XX_CS_HIGH;
#endif
}

static void ST77XX_Transmit(const uint8_t *pData, uint32_t Size, uint32_t Timeout)
{
#if ST77XX_HARDWARE_SPI
    // ST77XX_CS_LOW;
    /* Wait for SPI_MASTER Tx buffer empty */
    // while (SPI_I2S_Flag_Status_Get(SPI_MASTER, SPI_I2S_FLAG_TE) == RESET)
    //     ;
    /* Send SPI_MASTER data */
    for (int i = 0; i < Size; i++) {
        while (SPI_I2S_Flag_Status_Get(SPI_MASTER, SPI_I2S_FLAG_TE) == RESET)
            ;
        SPI_I2S_Data_Transmit(SPI_MASTER, pData[i]);
        // while (SPI_I2S_Flag_Status_Get(SPI_MASTER, SPI_I2S_FLAG_RNE) == RESET)
        //     ;
        // SPI_I2S_Data_Get(SPI_MASTER);
    }
    // ST77XX_CS_HIGH;
#else
    while (Size-- > 0)
    {
        ST77XX_TransmitByte(*(pData++));
    }
#endif
}

static void ST77XX_WriteCommand(uint8_t dat)
{
    ST77XX_DC_LOW;
    ST77XX_TransmitByte(dat);
    ST77XX_DC_HIGH;
}

static void ST77XX_WriteData(const uint8_t* buff, size_t buff_size)
{
    ST77XX_Transmit(buff, buff_size, HAL_MAX_DELAY);
}

static void ST77XX_WriteBuff(uint8_t* buff, size_t buff_size)
{
    while (buff_size--)
    {
        st77xx_buf[st77xx_buf_pt++] = *buff++;
        if (st77xx_buf_pt == ST77XX_BUF_SIZE)
        {
            ST77XX_Transmit(st77xx_buf, st77xx_buf_pt, HAL_MAX_DELAY);
            st77xx_buf_pt = 0;
        }
    }
}

static void ST77XX_FlushBuff(void)
{
    if (st77xx_buf_pt > 0)
    {
        ST77XX_Transmit(st77xx_buf, st77xx_buf_pt, HAL_MAX_DELAY);
        st77xx_buf_pt = 0;
    }
}

void ST77XX_ExecuteCommandList(const uint8_t *addr)
{
    uint8_t numCommands, numArgs;
    uint16_t ms;

    numCommands = *addr++;
    while (numCommands--)
    {
        uint8_t cmd = *addr++;
        ST77XX_WriteCommand(cmd);

        numArgs = *addr++;
        // If high bit set, delay follows args
        ms = numArgs & ST77XX_CMD_DELAY;
        numArgs &= ~ST77XX_CMD_DELAY;
        if (numArgs)
        {
            ST77XX_WriteData(addr, numArgs);
            addr += numArgs;
        }

        if (ms)
        {
            ms = *addr++;
            if (ms == 255)
                ms = 500;
            SysTick_Delay_Ms(ms);
        }
    }
}

static void ST77XX_SetAddrWindow(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2)
{
    // column address set
    ST77XX_WriteCommand(ST77XX_CASET);
    x1 = x1 + ST77XX_XSTART;
    x2 = x2 + ST77XX_XSTART;
    uint8_t data[] = { x1 >> 8, x1 & 0xFF, x2 >> 8, x2 % 0xFF };
    ST77XX_WriteData(data, sizeof(data));

    // row address set
    ST77XX_WriteCommand(ST77XX_RASET);
    y1 = y1 + ST77XX_YSTART;
    y2 = y2 + ST77XX_YSTART;
    data[0] = y1 >> 8;
    data[1] = y1 & 0xFF;
    data[2] = y2 >> 8;
    data[3] = y2 & 0xFF;
    ST77XX_WriteData(data, sizeof(data));

    // write to RAM
    ST77XX_WriteCommand(ST77XX_RAMWR);
}

void ST77XX_BackLight_On(void)
{
    ST77XX_BL_HIGH;
}

void ST77XX_BackLight_Off(void)
{
    ST77XX_BL_LOW;
}

void ST77XX_Fill(uint16_t x_start, uint16_t y_start, uint16_t x_end, uint16_t y_end, uint16_t color)
{
    uint16_t i,j;
    ST77XX_SetAddrWindow(x_start, y_start, x_end - 1, y_end - 1);
    for(i = y_start; i < y_end; i++)
    {
        for( j = x_start; j < x_end; j++)
        {
            ST77XX_WriteBuff((uint8_t *)&color, 2);
        }
    }
    ST77XX_FlushBuff();
}

void ST77XX_Clear(uint16_t color)
{
    ST77XX_Fill(0, 0, ST77XX_WIDTH, ST77XX_HEIGHT, color);
}

void ST77XX_DrawPoint(uint16_t x, uint16_t y, uint16_t color)
{
    ST77XX_SetAddrWindow( x, y, x, y);
    ST77XX_WriteData((uint8_t *)&color, 2);
}

void ST77XX_DrawLine(uint16_t x_start, uint16_t y_start, uint16_t x_end, uint16_t y_end, uint16_t color)
{
    uint16_t t;
    int xerr = 0, yerr=0, delta_x, delta_y, distance;
    int incx, incy, uRow, uCol;
    delta_x = x_end - x_start; //计算坐标增量 
    delta_y = y_end - y_start;
    uRow = x_start;//画线起点坐标
    uCol = y_start;

    if (delta_x > 0)
        incx = 1; //设置单步方向 
    else if (delta_x == 0)
        incx=0; //垂直线
    else
    {
        incx = -1;
        delta_x = -delta_x;
    }

    if (delta_y > 0)
        incy = 1;
    else if (delta_y == 0)
        incy=0; //水平线 
    else
    {
        incy = -1;
        delta_y = -delta_y;
    }
    
    if (delta_x > delta_y)
        distance = delta_x; //选取基本增量坐标轴 
    else
        distance = delta_y;

    for (t = 0; t < distance + 1; t++)
    {
        ST77XX_DrawPoint(uRow, uCol, color);
        xerr += delta_x;
        yerr += delta_y;
        if(xerr > distance)
        {
            xerr -= distance;
            uRow += incx;
        }
        if(yerr>distance)
        {
            yerr -= distance;
            uCol += incy;
        }
    }
}

void ST77XX_DrawRectangle(uint16_t x_start, uint16_t y_start, uint16_t x_end, uint16_t y_end, uint16_t color)
{
    ST77XX_DrawLine(x_start, y_start, x_end,   y_start, color);
    ST77XX_DrawLine(x_start, y_start, x_start, y_end,   color);
    ST77XX_DrawLine(x_start, y_end,   x_end,   y_end,   color);
    ST77XX_DrawLine(x_end,   y_start, x_end,   y_end,   color);
}

void ST77XX_DrawCircle(uint16_t x, uint16_t y, uint8_t radius, uint16_t color)
{
    int a = 0, b = radius;
    while (a <= b)
    {
        ST77XX_DrawPoint(x - b, y - a, color);
        ST77XX_DrawPoint(x - b, y + a, color);
        ST77XX_DrawPoint(x + b, y - a, color);
        ST77XX_DrawPoint(x + b, y + a, color);
        ST77XX_DrawPoint(x + a, y - b, color);
        ST77XX_DrawPoint(x - a, y - b, color);
        ST77XX_DrawPoint(x + a, y + b, color);
        ST77XX_DrawPoint(x - a, y + b, color);
        a++;
        if ((a * a + b * b) > (radius * radius))
        {
            b--;
        }
    }
}

void ST77XX_DrawImage(uint16_t x, uint16_t y, uint16_t w, uint16_t h, const uint16_t *data)
{
    if ((x >= ST77XX_WIDTH) || (y >= ST77XX_HEIGHT))
        return;
    if ((x + w - 1) >= ST77XX_WIDTH)
        return;
    if ((y + h - 1) >= ST77XX_HEIGHT)
        return;

    ST77XX_SetAddrWindow(x, y, x + w - 1, y + h - 1);
    ST77XX_WriteData((uint8_t *)data, sizeof(uint16_t) * w * h);
}

void ST77XX_DrawChar(uint16_t x, uint16_t y, char ch, FontDef_t* font, uint16_t color, uint16_t bgcolor)
{
    uint8_t b, i, j, k, bytes;

    ST77XX_SetAddrWindow(x, y, x + font->width - 1, y + font->height - 1);
    bytes = font->width / 8 + ((font->width % 8)? 1 : 0);

    for (i = 0; i < font->height; i++)
    {
        for (j = 0; j < bytes; j++)
        {
            b = font->data[((ch - 32) * font->height + i) * bytes + j];
            if (font->order == 0)
            {
                for (k = 0; k < 8 && k < font->width - j * 8; k++)
                {
                    if ((b << k) & 0x80)
                    {
                        ST77XX_WriteBuff((uint8_t *)&color, 2);
                    }
                    else
                    {
                        ST77XX_WriteBuff((uint8_t *)&bgcolor, 2);
                    }
                }
            }
            else
            {
                for (k = 0; k < 8 && k < font->width - j * 8; k++)
                {
                    if (b & (0x0001 << k))
                    {
                        ST77XX_WriteBuff((uint8_t *)&color, 2);
                    }
                    else
                    {
                        ST77XX_WriteBuff((uint8_t *)&bgcolor, 2);
                    }
                }
            }
        }

    }
    ST77XX_FlushBuff();
}

void ST77XX_DrawString(uint16_t x, uint16_t y, const char *p, FontDef_t* font, uint16_t color, uint16_t bgcolor)
{
    while (*p != '\0')
    {
        ST77XX_DrawChar(x, y, *p, font, color, bgcolor);
        x += font->width;
        p++;
    }
}

#define __LOGO_HEIGHT 60
#define __LOGO_WIDTH 160

// array size is 9600
static const uint8_t LOGO[] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xe7, 0xbc, 0x86, 0x57, 0x36, 0x1d, 0x17, 0x17, 0x16, 0x21, 0x39, 0x67, 0xa0, 0xd7, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe9, 0xaf, 0x5c, 0x24, 0x0f, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x00, 0x00, 0x07, 0x16, 0x44, 0x99, 0xe7, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xec, 0x9a, 0x3c, 0x09, 0x01, 0x00, 0x07, 0x01, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x39, 0xa4, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xba, 0x39, 0x07, 0x09, 0x3a, 0x65, 0x81, 0x8a, 0x91, 0x89, 0x6a, 0x46, 0x17, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x5a, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd9, 0x8c, 0x97, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xb7, 0xc0, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xcf, 0xd7, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf1, 0xa7, 0xa7, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd9, 0xf6, 0xff, 0xff, 0xf8, 0xea, 0xea, 0xea, 0xea, 0xea, 0xf9, 0xff, 0xff, 0xff, 0xfa, 0xd6, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xb7, 0x96, 0xba, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xa4, 0x84, 0xba, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xaa, 0x6f, 0xda, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe8, 0x6f, 0x24, 0x65, 0xb7, 0xe9, 0xf9, 0xfa, 0xff, 0xff, 0xff, 0xfa, 0xfa, 0xfa, 0xef, 0xba, 0x5f, 0x16, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x29, 0xd7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa0, 0x06, 0x25, 0xda, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xca, 0x1f, 0x06, 0xbf, 0xff, 0xfc, 0xf6, 0xf6, 0xc9, 0x09, 0x34, 0xe9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xda, 0x19, 0x0f, 0xba, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9c, 0x3f, 0x3f, 0x3f, 0x3f, 0x3f, 0x3f, 0x3f, 0x40, 0x3c, 0x8a, 0xf6, 0xff, 0xff, 0xb0, 0x17, 0x5c, 0xea, 0xff, 0xb1, 0x0c, 0x0c, 0x0c, 0x0c, 0x09, 0xba, 0xff, 0xff, 0xff, 0x89, 0x16, 0x64, 0xf1, 0xff, 0xff, 0xff, 0x47, 0x06, 0x64, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0x46, 0x01, 0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb7, 0x49, 0x4e, 0x4c, 0x4c, 0x46, 0x08, 0x07, 0x29, 0x4e, 0x4c, 0x4c, 0x4c, 0xa1, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0x60, 0x7a, 0xd6, 0xf7, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xfc, 0xf6, 0xc4, 0x4f, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x06, 0x00, 0x39, 0xd7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xe6, 0xe0, 0xe0, 0xe1, 0xca, 0x09, 0x24, 0xaa, 0xe0, 0xe0, 0xe0, 0xe1, 0xfc, 0xff, 0xff, 0xf7, 0x56, 0x06, 0x00, 0x46, 0xde, 0xf0, 0x44, 0x41, 0xb0, 0x09, 0x2a, 0xe9, 0xfc, 0xc1, 0x9a, 0xa0, 0x9a, 0x89, 0x0a, 0x08, 0x74, 0xa0, 0x9a, 0xa0, 0xba, 0xfc, 0xff, 0xff, 0x7c, 0x04, 0x04, 0x04, 0x04, 0x04, 0x06, 0x00, 0x00, 0x06, 0x17, 0xbf, 0xff, 0xff, 0xc8, 0x29, 0x07, 0x5a, 0xfa, 0xaa, 0x00, 0x14, 0x2a, 0x0a, 0x01, 0xba, 0xff, 0xff, 0xff, 0xa7, 0x1d, 0x07, 0x69, 0xf6, 0xff, 0xff, 0x49, 0x00, 0x64, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf1, 0x40, 0x00, 0x7c, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9c, 0x07, 0x16, 0x31, 0x1e, 0x1c, 0x37, 0x37, 0x20, 0x1d, 0x2f, 0x17, 0x00, 0x7a, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xd9, 0x78, 0xca, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0x80, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x56, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd9, 0x3b, 0x2a, 0x2a, 0x2a, 0x28, 0x06, 0x18, 0x27, 0x2c, 0x29, 0x29, 0x2c, 0xec, 0xff, 0xf8, 0x86, 0x07, 0x16, 0x29, 0x00, 0x56, 0xda, 0x1e, 0x17, 0xa7, 0x0a, 0x2a, 0xec, 0xf9, 0x58, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x01, 0x00, 0x00, 0x06, 0x54, 0xf9, 0xff, 0xff, 0xca, 0xa6, 0xa4, 0xa1, 0xa4, 0x9a, 0x60, 0x01, 0x01, 0x17, 0x99, 0xfa, 0xff, 0xff, 0xff, 0xc0, 0x28, 0x86, 0xf9, 0x8a, 0x06, 0x69, 0xe6, 0x41, 0x07, 0xbc, 0xff, 0xff, 0xff, 0xf9, 0xb6, 0x25, 0xaa, 0xf9, 0xff, 0xff, 0x49, 0x00, 0x64, 0xff, 0xff, 0xff, 0xfc, 0xf9, 0xf8, 0xf8, 0xf8, 0xea, 0x39, 0x06, 0x86, 0xf8, 0xf8, 0xf8, 0xf8, 0xf8, 0xfc, 0xa7, 0x1d, 0x3f, 0x78, 0x24, 0x27, 0x76, 0x7b, 0x2c, 0x20, 0x70, 0x3f, 0x19, 0x89, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xea, 0xb2, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0x87, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x97, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0x16, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x01, 0x07, 0x00, 0x00, 0x04, 0xe9, 0xf6, 0x84, 0x07, 0x09, 0x96, 0xe0, 0x1e, 0x07, 0x5a, 0x1e, 0x17, 0xa7, 0x0f, 0x2a, 0xe9, 0xf7, 0x58, 0x06, 0x28, 0x61, 0x56, 0x08, 0x04, 0x48, 0x61, 0x36, 0x00, 0x57, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xdf, 0x61, 0x09, 0x00, 0x3a, 0xc0, 0xff, 0xff, 0xff, 0xec, 0xe0, 0xe1, 0xc8, 0xf4, 0xa7, 0x1c, 0x07, 0xb0, 0xf6, 0x49, 0x00, 0x6c, 0xa1, 0xec, 0xe4, 0xde, 0xdf, 0xcf, 0xf6, 0xe4, 0xe1, 0xe1, 0x41, 0x00, 0x5a, 0xe1, 0xe6, 0xe9, 0xe8, 0x59, 0x50, 0x50, 0x56, 0x49, 0x16, 0x00, 0x2f, 0x50, 0x50, 0x50, 0x51, 0x65, 0xe9, 0xf9, 0xf0, 0x88, 0x4f, 0x07, 0x0a, 0x4f, 0x56, 0x0f, 0x04, 0x48, 0x71, 0xe1, 0xfa, 
  0xff, 0xff, 0xff, 0xff, 0xf9, 0xf0, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x81, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x7a, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xca, 0xba, 0x76, 0x57, 0xc4, 0xc8, 0xc8, 0xc7, 0x5e, 0x7a, 0xaf, 0xc9, 0xfa, 0xba, 0x17, 0x00, 0x49, 0xb2, 0xb9, 0x77, 0x08, 0x39, 0x1a, 0x17, 0xa4, 0x0a, 0x2a, 0xe9, 0xfa, 0x58, 0x00, 0x50, 0xaa, 0x94, 0x0f, 0x09, 0x7c, 0xaa, 0x60, 0x00, 0x54, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb7, 0x09, 0x06, 0x87, 0xe9, 0xff, 0xff, 0xff, 0xf9, 0x7c, 0x10, 0x10, 0x21, 0xca, 0x46, 0x07, 0x59, 0xf9, 0xff, 0x8a, 0x09, 0x07, 0x20, 0xca, 0x2c, 0x10, 0x0f, 0x0f, 0x99, 0x26, 0x0f, 0x0f, 0x04, 0x00, 0x06, 0x0f, 0x0a, 0x46, 0xdf, 0x0a, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0xe6, 0xff, 0xfc, 0x80, 0x29, 0x04, 0x07, 0x2a, 0x29, 0x08, 0x06, 0x26, 0x56, 0xe9, 0xff, 
  0xff, 0xff, 0xfc, 0xf6, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xe7, 0xea, 0xf9, 0xff, 0xff, 0xff, 0xfc, 0xe4, 0xcf, 0xcf, 0xe6, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xe0, 0xe4, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf1, 0xe1, 0xe9, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xc6, 0x17, 0x17, 0xd4, 0xff, 0xff, 0xe6, 0x16, 0x0f, 0x9a, 0xff, 0xff, 0xf8, 0x91, 0x0a, 0x09, 0x09, 0x0f, 0x09, 0x1a, 0xb7, 0x1f, 0x17, 0xa8, 0x09, 0x2f, 0xe9, 0xf7, 0x58, 0x01, 0x07, 0x07, 0x06, 0x06, 0x06, 0x07, 0x07, 0x04, 0x00, 0x57, 0xf7, 0xf8, 0xc0, 0xb7, 0xb7, 0xb7, 0xb7, 0x7f, 0x06, 0x10, 0xb4, 0xb7, 0xb7, 0xb6, 0xb7, 0xde, 0x86, 0x1f, 0x07, 0x18, 0xd6, 0xb6, 0x57, 0xac, 0xbc, 0xbc, 0xb0, 0x76, 0x6f, 0xa8, 0xe7, 0x38, 0x1c, 0x06, 0x00, 0x98, 0x2c, 0x16, 0x16, 0x06, 0x00, 0x0a, 0x18, 0x16, 0x44, 0xf6, 0x94, 0x88, 0x8f, 0x89, 0x5f, 0x06, 0x00, 0x08, 0x76, 0x89, 0x8f, 0x89, 0x97, 0xf6, 0xba, 0x64, 0x50, 0x3c, 0x06, 0x0a, 0x3a, 0x3f, 0x0b, 0x06, 0x37, 0x49, 0x5f, 0xa7, 
  0xff, 0xff, 0xe6, 0x49, 0x8a, 0xf9, 0xff, 0xff, 0xff, 0xf9, 0xc4, 0x5a, 0x36, 0x36, 0x9a, 0xfc, 0xff, 0xfc, 0x90, 0x51, 0x68, 0x66, 0x4f, 0xa9, 0xfc, 0xff, 0xff, 0xf9, 0xc7, 0x57, 0x30, 0x39, 0xbf, 0xf9, 0xff, 0xf9, 0xc6, 0x5a, 0x34, 0x36, 0x9c, 0xfa, 0xff, 0xff, 0xff, 0xfa, 0xe9, 0x1b, 0x07, 0xa4, 0xff, 0xff, 0xc0, 0x00, 0x11, 0xc7, 0xff, 0xff, 0xff, 0xf6, 0x30, 0x07, 0x57, 0x6a, 0x09, 0x24, 0xc6, 0x1e, 0x17, 0xa7, 0x0a, 0x30, 0xea, 0xf7, 0x58, 0x00, 0x29, 0x62, 0x56, 0x06, 0x07, 0x44, 0x61, 0x36, 0x00, 0x54, 0xf7, 0xe6, 0x26, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x01, 0x00, 0x00, 0x01, 0x01, 0x94, 0xf0, 0xca, 0x1b, 0x11, 0xd7, 0x88, 0x07, 0x04, 0x07, 0x07, 0x04, 0x07, 0x16, 0xb2, 0xf9, 0xe1, 0xc9, 0x29, 0x06, 0xb7, 0xca, 0xca, 0xca, 0x39, 0x01, 0x56, 0xc9, 0xc9, 0xd7, 0xfc, 0xff, 0xff, 0xff, 0xff, 0x7c, 0x01, 0x00, 0x06, 0x86, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xaa, 0x40, 0x27, 0x00, 0x01, 0x27, 0x3c, 0x3c, 0x3a, 0x0c, 0x00, 0x06, 0x29, 0x89, 
  0xff, 0xff, 0x94, 0x00, 0xba, 0xff, 0xff, 0xff, 0xf6, 0x84, 0x0c, 0x4c, 0x70, 0x2a, 0x0c, 0xd6, 0xfa, 0x86, 0x76, 0xf6, 0xf9, 0xff, 0xe9, 0x56, 0xc7, 0xff, 0xff, 0xaa, 0x09, 0x51, 0x69, 0x1d, 0x3c, 0xec, 0xf9, 0x84, 0x0f, 0x49, 0x74, 0x29, 0x14, 0xc4, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x3f, 0x01, 0x76, 0xfc, 0xfc, 0x84, 0x00, 0x39, 0xe9, 0xff, 0xff, 0xff, 0xf6, 0x34, 0x09, 0xc6, 0xec, 0x07, 0x29, 0xd6, 0x1e, 0x17, 0xa4, 0x0c, 0x2a, 0xe9, 0xf7, 0x59, 0x01, 0x46, 0x94, 0x7f, 0x09, 0x09, 0x69, 0x94, 0x51, 0x00, 0x57, 0xf7, 0xec, 0x59, 0x3f, 0x3f, 0x3f, 0x3f, 0x2c, 0x06, 0x07, 0x3c, 0x3f, 0x3f, 0x3f, 0x41, 0xa9, 0xff, 0xe7, 0x1c, 0x16, 0xd6, 0xaa, 0x1c, 0x07, 0x50, 0x59, 0x3c, 0x00, 0x1d, 0xd9, 0xff, 0xff, 0xea, 0x36, 0x01, 0xb9, 0xff, 0xfa, 0xff, 0x49, 0x00, 0x65, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe1, 0x21, 0x06, 0x1a, 0x01, 0x1c, 0xd4, 0xff, 0xff, 0xff, 0xff, 0xb9, 0x78, 0x24, 0x00, 0x0f, 0x67, 0x7c, 0x7c, 0x7b, 0x38, 0x01, 0x07, 0x2a, 0x86, 
  0xff, 0xf1, 0x49, 0x26, 0xec, 0xff, 0xff, 0xff, 0x89, 0x16, 0x8c, 0xf6, 0xfc, 0xb7, 0x1f, 0xc0, 0xd6, 0x48, 0xec, 0x97, 0x50, 0x50, 0xc7, 0xaf, 0x78, 0xfc, 0xe9, 0x3a, 0x27, 0xe6, 0xfa, 0xb7, 0xd8, 0xfa, 0x96, 0x09, 0x97, 0xf1, 0xfc, 0xa9, 0x29, 0xbc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x77, 0x00, 0x39, 0xfa, 0xe9, 0x46, 0x01, 0x7f, 0xfc, 0xff, 0xff, 0xff, 0xf6, 0x36, 0x0f, 0x69, 0x36, 0x00, 0x3c, 0xe1, 0x1d, 0x17, 0xa7, 0x0a, 0x2a, 0xe9, 0xfa, 0x58, 0x00, 0x01, 0x07, 0x06, 0x00, 0x06, 0x06, 0x07, 0x06, 0x00, 0x57, 0xf7, 0xfc, 0xf4, 0xf1, 0xf1, 0xf1, 0xf1, 0xac, 0x08, 0x16, 0xf0, 0xf6, 0xf1, 0xf1, 0xf1, 0xf8, 0xff, 0xe6, 0x1c, 0x09, 0x6a, 0xaf, 0x57, 0x06, 0x7c, 0xd8, 0x49, 0x01, 0x77, 0xfa, 0xff, 0xff, 0xe9, 0x31, 0x00, 0x9c, 0xa6, 0xf9, 0xff, 0x4a, 0x00, 0x65, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0x65, 0x07, 0x17, 0xba, 0x1a, 0x06, 0x4c, 0xf1, 0xff, 0xff, 0xff, 0x89, 0x11, 0x1b, 0x00, 0x0f, 0x2c, 0x27, 0x28, 0x2a, 0x27, 0x00, 0x08, 0x2a, 0xa7, 
  0xff, 0xc7, 0x17, 0x78, 0xfc, 0xff, 0xff, 0xda, 0x21, 0x56, 0xf9, 0xfc, 0xff, 0xf1, 0xd4, 0xf7, 0x94, 0x8f, 0xc7, 0x50, 0xd7, 0x39, 0xd6, 0xca, 0x69, 0xf9, 0xe6, 0x36, 0x07, 0x4e, 0xb6, 0xf7, 0xff, 0xd7, 0x28, 0x51, 0xf4, 0xff, 0xff, 0xef, 0xd7, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa0, 0x16, 0x31, 0xf9, 0xca, 0x14, 0x08, 0xc7, 0xff, 0xff, 0xff, 0xff, 0xf1, 0x36, 0x11, 0x86, 0x1f, 0x36, 0x7a, 0xde, 0x94, 0x91, 0xba, 0x09, 0x2f, 0xe9, 0xf7, 0x5a, 0x04, 0x34, 0x68, 0x59, 0x09, 0x04, 0x4f, 0x6a, 0x68, 0x65, 0x2f, 0xb6, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb7, 0x09, 0x17, 0xfc, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe4, 0x1f, 0x06, 0x07, 0x5a, 0xc1, 0x25, 0x09, 0x30, 0x07, 0x36, 0xe6, 0xff, 0xff, 0xff, 0xe9, 0x36, 0x00, 0x19, 0x29, 0xe6, 0xff, 0x49, 0x00, 0x65, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x8a, 0x07, 0x07, 0x77, 0xf9, 0x86, 0x07, 0x07, 0x68, 0xe8, 0xff, 0xff, 0xf6, 0xba, 0xaa, 0x00, 0x4c, 0xc8, 0x50, 0x41, 0xba, 0xaa, 0x06, 0x3c, 0xd0, 0xf8, 
  0xff, 0x86, 0x0c, 0xc1, 0xff, 0xff, 0xfc, 0x86, 0x0a, 0xb6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xa7, 0x97, 0x74, 0xf6, 0x38, 0xe8, 0x9a, 0x89, 0xff, 0xfc, 0xb2, 0x26, 0x01, 0x0c, 0x97, 0xff, 0x90, 0x09, 0xaa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xba, 0xa4, 0xa0, 0x89, 0x67, 0x8f, 0xa0, 0x61, 0x06, 0x1f, 0x96, 0xa0, 0xa0, 0xbf, 0xfc, 0xf4, 0x31, 0x0c, 0xc0, 0xe8, 0xf1, 0x40, 0x37, 0xe4, 0xff, 0xd0, 0x0a, 0x31, 0xea, 0xfc, 0xbc, 0x98, 0xca, 0xff, 0xe0, 0x19, 0x0a, 0xaa, 0xf6, 0xf4, 0xc7, 0x04, 0x1c, 0xd6, 0xff, 0xff, 0xf9, 0xf9, 0xff, 0xaf, 0x08, 0x17, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xca, 0x17, 0x00, 0x1c, 0xc7, 0xd9, 0x59, 0x06, 0x01, 0x07, 0x76, 0xe8, 0xfc, 0xff, 0xff, 0xd4, 0x1f, 0x00, 0x00, 0x48, 0xe6, 0xff, 0x49, 0x00, 0x65, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x65, 0x08, 0x00, 0x46, 0xe7, 0xff, 0xf6, 0x56, 0x00, 0x00, 0x47, 0xc6, 0xfc, 0xfc, 0xfc, 0xcf, 0x20, 0x48, 0x5a, 0x07, 0x25, 0x46, 0x47, 0x04, 0x58, 0xf6, 0xff, 
  0xec, 0x29, 0x3c, 0xf9, 0xff, 0xff, 0xfc, 0x49, 0x1d, 0xd6, 0xff, 0xff, 0xc8, 0x3a, 0xd6, 0xff, 0x97, 0x89, 0xca, 0x3f, 0x5a, 0x41, 0x5f, 0x5f, 0xec, 0xff, 0xff, 0xff, 0xf8, 0x7c, 0x04, 0x64, 0xff, 0x49, 0x19, 0xd9, 0xff, 0xff, 0xd9, 0x2f, 0xc8, 0xff, 0xff, 0xfc, 0x46, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x50, 0xf6, 0xf6, 0x46, 0x01, 0x25, 0x39, 0x36, 0x06, 0x27, 0x84, 0x46, 0x30, 0x01, 0x37, 0xec, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0x24, 0x00, 0x07, 0x0a, 0x0a, 0x07, 0x00, 0x46, 0xe9, 0xff, 0xff, 0xea, 0x48, 0x1c, 0x10, 0x00, 0x25, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x82, 0x07, 0x36, 0x87, 0x2c, 0x07, 0x01, 0x09, 0x29, 0x07, 0x00, 0x09, 0x48, 0xde, 0xff, 0x7b, 0x00, 0x0c, 0x86, 0xf6, 0xfc, 0xff, 0x49, 0x00, 0x65, 0xff, 0xff, 0xff, 0xe1, 0x28, 0x00, 0x01, 0x51, 0xe7, 0xff, 0xff, 0xff, 0xe8, 0x5c, 0x00, 0x00, 0x24, 0xdc, 0xca, 0x89, 0x69, 0x36, 0x09, 0x06, 0x49, 0x99, 0x49, 0x1c, 0x00, 0x10, 0x48, 0xa4, 
  0xb2, 0x0a, 0x7a, 0xd7, 0xd6, 0xea, 0xf9, 0x4c, 0x10, 0x9c, 0xde, 0xb7, 0x37, 0x65, 0xf7, 0xff, 0xd6, 0x41, 0xd9, 0xe7, 0xe6, 0xe7, 0x9a, 0xd9, 0xff, 0xda, 0x79, 0xb9, 0xd9, 0x6a, 0x18, 0xb7, 0xfc, 0x4a, 0x08, 0x99, 0xdf, 0xb8, 0x37, 0x68, 0xf0, 0xff, 0xff, 0xf9, 0x7f, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x86, 0xf7, 0xfc, 0xb1, 0x36, 0x25, 0x24, 0x24, 0x36, 0x9a, 0xb1, 0x0f, 0x0a, 0x24, 0x94, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x90, 0x26, 0x17, 0x17, 0x16, 0x17, 0x28, 0xb7, 0xfc, 0xff, 0xff, 0xf9, 0x89, 0x0a, 0x11, 0x2a, 0x96, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x64, 0xd7, 0xe1, 0x25, 0x30, 0x69, 0xc7, 0xe6, 0x99, 0x47, 0x18, 0x86, 0xfa, 0xff, 0xcc, 0x44, 0xaf, 0xfa, 0xff, 0xff, 0xff, 0x49, 0x09, 0x66, 0xff, 0xff, 0xff, 0xfc, 0xac, 0x36, 0x7c, 0xf1, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0x86, 0x2f, 0xa8, 0xfc, 0xb9, 0x26, 0x25, 0x39, 0x70, 0xb7, 0xf0, 0xf9, 0xf6, 0xd9, 0x9c, 0x50, 0x1c, 0x74, 
  0x67, 0x09, 0x1c, 0x25, 0x2a, 0xaa, 0xfc, 0x97, 0x16, 0x14, 0x29, 0x1e, 0x76, 0xe8, 0xff, 0xff, 0xfa, 0xb0, 0x49, 0x7c, 0x97, 0x76, 0x68, 0xe1, 0xff, 0xa9, 0x17, 0x1c, 0x2c, 0x20, 0x90, 0xf9, 0xff, 0x9a, 0x11, 0x11, 0x2c, 0x21, 0x69, 0xef, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xfa, 0xf9, 0xff, 0xff, 0xff, 0xea, 0xdc, 0xd9, 0xd9, 0xe8, 0xfc, 0xf6, 0xbc, 0xc0, 0xd7, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xd9, 0xc7, 0xc6, 0xc7, 0xc7, 0xe6, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xe9, 0xb9, 0xc9, 0xd9, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xf6, 0xfc, 0xff, 0xd7, 0xe9, 0xf9, 0xff, 0xff, 0xfc, 0xf7, 0xca, 0xf0, 0xff, 0xff, 0xfa, 0xe4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc7, 0xb0, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xe0, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xdf, 0xf8, 0xff, 0xf8, 0xd0, 0xd8, 0xf0, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xf6, 0xd0, 0xef, 
  0xb2, 0xa6, 0xa6, 0xa6, 0xac, 0xec, 0xff, 0xf9, 0xba, 0x88, 0x94, 0xca, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe1, 0xac, 0x9f, 0xbc, 0xf7, 0xff, 0xff, 0xf9, 0xb9, 0x87, 0x9a, 0xd6, 0xfc, 0xff, 0xff, 0xf9, 0xc0, 0x8a, 0x9a, 0xc8, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xfa, 0xfa, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xa0, 0x68, 0x66, 0x66, 0x66, 0x67, 0x69, 0x69, 0x68, 0x76, 0xdc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xe8, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xa9, 0x0a, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x57, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xf6, 0x8f, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xa7, 0x18, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x26, 0xd0, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf4, 0xe6, 0xec, 0xf9, 0xff, 0xf6, 0xf7, 0xe9, 0xfc, 0xf9, 0xec, 0xfc, 0xff, 0xfc, 0xe1, 0xe0, 0xfa, 0xf9, 0xe6, 0xe6, 0xe9, 0xf9, 0xec, 0xf9, 0xff, 0xff, 0xfa, 0xe0, 0xde, 0xfc, 0xf9, 0xe1, 0xde, 0xfa, 0xff, 0xf8, 0xda, 0xe6, 0xfc, 0xff, 0xff, 0xff, 0xf7, 0xd9, 0xe9, 0xf9, 0xfc, 0xe7, 0xd9, 0xf8, 0xff, 0xf4, 0xf0, 0xff, 0xf9, 0xe9, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xf9, 0xa9, 0x77, 0xf0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0x76, 0x09, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0xb9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x94, 0x54, 0x62, 0x86, 0xff, 0x91, 0xa7, 0x88, 0xa7, 0xd7, 0x5a, 0xff, 0xff, 0xa7, 0x5c, 0x6a, 0xc1, 0xe1, 0x76, 0x60, 0x3c, 0xf1, 0x5a, 0xdc, 0xff, 0xff, 0x86, 0x60, 0x69, 0xca, 0xa9, 0x5a, 0x6c, 0xc7, 0xf6, 0x77, 0x69, 0x6a, 0xde, 0xff, 0xff, 0xef, 0x6a, 0x6a, 0x74, 0xdf, 0xa0, 0x59, 0x66, 0x69, 0xfa, 0x99, 0x56, 0xf9, 0xba, 0x46, 0xe9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xf9, 0x5a, 0x50, 0xca, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xb0, 0x36, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x16, 0xa6, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xf0, 0xfc, 0x89, 0xa4, 0xec, 0x56, 0xd9, 0x89, 0xa0, 0xe9, 0x5f, 0x7a, 0xb1, 0xff, 0xff, 0x7c, 0x7c, 0xe6, 0xfa, 0xfc, 0xf9, 0x77, 0xac, 0xff, 0x57, 0xda, 0xff, 0xdc, 0x57, 0xeb, 0xfa, 0xf8, 0x86, 0x7b, 0xe0, 0xf8, 0xba, 0x62, 0xf9, 0xf8, 0xfc, 0xff, 0xff, 0xaf, 0x77, 0xf9, 0xf8, 0xe7, 0x41, 0xf8, 0xfa, 0x64, 0xc7, 0x9f, 0x46, 0xd0, 0x7c, 0x46, 0xe4, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 0xef, 0xec, 
  0xff, 0xff, 0xff, 0xff, 0xd9, 0x3a, 0x1d, 0x86, 0xd7, 0xf4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0xe1, 0xaa, 0x46, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0xa4, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe1, 0xa6, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xaf, 0xf6, 0x8a, 0xa4, 0xf9, 0x6a, 0xc6, 0x89, 0xa7, 0xff, 0x7f, 0x4e, 0xf6, 0xff, 0xff, 0xe4, 0x80, 0x50, 0xba, 0xff, 0xb7, 0x70, 0xf4, 0xff, 0x56, 0xda, 0xff, 0xc6, 0x67, 0xf9, 0xff, 0xff, 0xe8, 0x84, 0x49, 0xba, 0xac, 0x7c, 0xff, 0xff, 0xff, 0xff, 0xff, 0x97, 0x94, 0xfc, 0xff, 0xe4, 0x46, 0xf9, 0xfa, 0x7f, 0xa9, 0x9a, 0x78, 0x84, 0x77, 0x59, 0xd9, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa7, 0xa6, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xcf, 0x29, 0x00, 0x1b, 0x54, 0x99, 0xc7, 0xe0, 0xef, 0xf4, 0xec, 0xdf, 0xc7, 0x9c, 0x5f, 0x28, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x31, 0xc6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xff, 0xff, 0x89, 0xa4, 0xe6, 0x48, 0xe7, 0x89, 0xa0, 0xff, 0xaa, 0x7c, 0xf9, 0xe6, 0xf9, 0xde, 0xf6, 0xa7, 0x69, 0xec, 0x51, 0xd9, 0xfa, 0xfc, 0x56, 0xd7, 0xf9, 0xe6, 0x4c, 0xe0, 0xf6, 0xec, 0xe1, 0xf6, 0xb8, 0x60, 0xc6, 0x54, 0xf7, 0xef, 0xf4, 0xec, 0xf6, 0xba, 0x5f, 0xf8, 0xec, 0xe4, 0x49, 0xe0, 0xea, 0x5a, 0xd8, 0x99, 0xa4, 0x50, 0xaa, 0x5a, 0xe6, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x49, 0x06, 0x00, 0x00, 0x00, 0x07, 0x0f, 0x14, 0x0a, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0x77, 0xf1, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa6, 0x56, 0x62, 0xb0, 0xff, 0xa6, 0xb8, 0xff, 0xba, 0x9a, 0xf8, 0x59, 0xe8, 0x9a, 0x59, 0x5a, 0xc0, 0xaa, 0x4f, 0x65, 0x74, 0xe9, 0x71, 0x5a, 0x6c, 0xe6, 0xaa, 0x59, 0x58, 0xc7, 0x9c, 0x58, 0x56, 0xc7, 0xf7, 0x99, 0x57, 0x62, 0xd7, 0x8a, 0xaa, 0xf6, 0x90, 0x59, 0x65, 0xd9, 0xca, 0x57, 0x59, 0x99, 0xfc, 0xaa, 0xba, 0xca, 0xf7, 0x7c, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf1, 0x94, 0x29, 0x01, 0x00, 0x00, 0x01, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x16, 0x62, 0xc8, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xef, 0xf6, 0xfc, 0xff, 0xf9, 0xf9, 0xff, 0xfa, 0xf8, 0xfc, 0xf4, 0xfc, 0xfc, 0xef, 0xf1, 0xff, 0xf8, 0xf0, 0xee, 0xf6, 0xf9, 0xf7, 0xec, 0xf0, 0xfc, 0xf9, 0xf0, 0xef, 0xfc, 0xf9, 0xec, 0xf1, 0xf9, 0xff, 0xfc, 0xe9, 0xf6, 0xfc, 0xf8, 0xf9, 0xff, 0xfa, 0xeb, 0xf8, 0xfa, 0xfa, 0xf1, 0xf0, 0xfc, 0xff, 0xfc, 0xfa, 0xfa, 0xff, 0xf6, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xda, 0x86, 0x2a, 0x0a, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x10, 0x2a, 0x74, 0xc9, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe9, 0xb8, 0x7a, 0x40, 0x1f, 0x0c, 0x0a, 0x0a, 0x0a, 0x0a, 0x0f, 0x2a, 0x49, 0x80, 0xc0, 0xe9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa0, 0xba, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2a, 0x56, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3c, 0x61, 0xb5, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb9, 0x30, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x4a, 0x00, 0x98, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xe7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xe7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xea, 0xc1, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xea, 0xea, 0xea, 0xea, 0xea, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x76, 0x01, 0x3b, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc7, 0x00, 0x00, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf4, 0x00, 0x06, 0xb9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdc, 0xa9, 0x6a, 0x36, 0x46, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x81, 0x00, 0xa9, 0xff, 0xcc, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x00, 0x9a, 0xff, 0xff, 0xff, 0x99, 0x06, 0x00, 0xe7, 0xff, 0xff, 0xcf, 0x47, 0x00, 0x00, 0x00, 0x29, 0xca, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0b, 0x2a, 0xb9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa5, 0x00, 0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0x00, 0x3a, 0xbc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc0, 0x37, 0xfa, 0xd7, 0xd8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x26, 0x00, 0xe9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xba, 0x06, 0x27, 0x74, 0x68, 0x46, 0x11, 0x00, 0x00, 0x00, 0x16, 0x4a, 0xe7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd9, 0x56, 0x00, 0x2a, 0x1f, 0x00, 0x17, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x06, 0xa2, 0xff, 0xff, 0xff, 0x9c, 0x00, 0x00, 0xe8, 0xff, 0xe7, 0x18, 0x00, 0x06, 0x29, 0x06, 0x00, 0x0a, 0xf0, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x16, 0x06, 0x00, 0x00, 0xb0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb6, 0x00, 0x7c, 0xff, 0xfa, 0xba, 0x82, 0xac, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x86, 0x06, 0x2a, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xa3, 0x64, 0x20, 0x00, 0x00, 0xa8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x29, 0x01, 0xff, 0xff, 0xd9, 0x97, 0x84, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x00, 0x0c, 0x3e, 0x49, 0x57, 0x76, 0x95, 0xb6, 0xd9, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xda, 0x4b, 0x10, 0x00, 0x00, 0x06, 0x2a, 0x66, 0xa2, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x00, 0xa6, 0xff, 0xff, 0xff, 0x99, 0x06, 0x00, 0xe8, 0xff, 0x67, 0x00, 0x1e, 0xd9, 0xff, 0xc7, 0x01, 0x00, 0x78, 0xff, 0xff, 0x00, 0x00, 0x6a, 0xff, 0xfa, 0xe6, 0x49, 0x00, 0x24, 0xff, 0xff, 0xff, 0xff, 0xc0, 0xca, 0xef, 0xd7, 0xac, 0x60, 0x00, 0x1e, 0x1e, 0x01, 0x00, 0x00, 0x00, 0x56, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xac, 0x86, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x47, 0x76, 0x94, 0xe7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb5, 0xe6, 0xe6, 0xc6, 0x95, 0x29, 0x06, 0x1e, 0x10, 0x00, 0x01, 0x01, 0x0c, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x17, 0x36, 0xff, 0xff, 0xff, 0x77, 0x10, 0x68, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc0, 0x99, 0xc6, 0x76, 0x00, 0xa3, 0x91, 0x62, 0xd9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xff, 0x9c, 0x00, 0x00, 0xe8, 0xff, 0x3b, 0x01, 0x65, 0xff, 0xff, 0xfa, 0x62, 0x00, 0x25, 0xff, 0xff, 0x00, 0x01, 0x69, 0xff, 0xff, 0xff, 0xa4, 0x00, 0x00, 0xee, 0xff, 0xff, 0xff, 0x89, 0x00, 0x00, 0x01, 0x0c, 0x29, 0x00, 0x56, 0xca, 0xe7, 0xe6, 0x29, 0x01, 0x01, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xac, 0x56, 0x69, 0x00, 0x18, 0xa9, 0xca, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0x01, 0x27, 0x09, 0x00, 0xb0, 0xdc, 0xe6, 0x6a, 0x01, 0x00, 0x6a, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0x00, 0x5e, 0xff, 0xff, 0xff, 0xc1, 0x00, 0x00, 0xf4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xaf, 0x71, 0x29, 0x00, 0x00, 0x00, 0x47, 0xa6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xff, 0x99, 0x06, 0x00, 0xe8, 0xff, 0x4c, 0x01, 0x17, 0xff, 0xff, 0xff, 0xc4, 0xbc, 0xb9, 0xff, 0xff, 0x00, 0x00, 0x6a, 0xff, 0xff, 0xff, 0x87, 0x00, 0x00, 0xfa, 0xff, 0xff, 0xff, 0xe7, 0x00, 0x34, 0xff, 0xff, 0xba, 0x06, 0x9a, 0xff, 0xfa, 0xff, 0x1e, 0x00, 0x51, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x38, 0x74, 0xf4, 0xff, 0xff, 0xff, 0xff, 0xff, 0x81, 0x06, 0x89, 0xc4, 0x01, 0x65, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x30, 0x00, 0xba, 0xff, 0xff, 0x27, 0x0b, 0xff, 0xff, 0xff, 0x9c, 0x00, 0x1a, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd6, 0x00, 0x7c, 0xff, 0xff, 0xff, 0xff, 0x00, 0x25, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9a, 0x34, 0x46, 0x25, 0x01, 0x95, 0xff, 0xfa, 0xdc, 0xb9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xff, 0x9c, 0x00, 0x00, 0xe8, 0xff, 0xa4, 0x00, 0x00, 0x37, 0xa6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x06, 0x59, 0xe7, 0xe4, 0xb9, 0x16, 0x01, 0x54, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3a, 0x14, 0xff, 0xb0, 0x61, 0x00, 0x01, 0x06, 0x1f, 0xe0, 0x00, 0x09, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x66, 0x00, 0x5a, 0xff, 0xff, 0xff, 0xff, 0xc1, 0x00, 0x8a, 0xdc, 0x95, 0x1d, 0x00, 0x60, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb5, 0x06, 0xa1, 0xd6, 0x88, 0x0b, 0x00, 0x01, 0x0a, 0x76, 0x67, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa9, 0x01, 0x99, 0xff, 0xff, 0xff, 0xff, 0x00, 0x25, 0xe4, 0xa9, 0x99, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x69, 0x00, 0x60, 0x50, 0x20, 0x06, 0x00, 0x2c, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xff, 0x99, 0x06, 0x00, 0xe8, 0xff, 0xff, 0x85, 0x00, 0x00, 0x00, 0x27, 0x99, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x56, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x76, 0x00, 0x68, 0x39, 0x2f, 0x00, 0x56, 0x94, 0xe7, 0xa5, 0x00, 0x69, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x79, 0x77, 0xff, 0xb1, 0xff, 0x77, 0x06, 0x00, 0x00, 0x0c, 0x56, 0x99, 0x46, 0x2a, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xeb, 0x00, 0x77, 0x56, 0x36, 0x06, 0x0c, 0x77, 0xb9, 0xff, 0x1d, 0x00, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x71, 0x01, 0xca, 0xff, 0xc8, 0xa9, 0x6a, 0x00, 0x00, 0x00, 0x00, 0x25, 0xf4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe8, 0xb1, 0x96, 0x71, 0x44, 0x0b, 0x00, 0x01, 0x26, 0x56, 0x77, 0x97, 0xb7, 0xea, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xff, 0xa0, 0x00, 0x00, 0xe8, 0xff, 0xff, 0xff, 0xc8, 0x62, 0x00, 0x06, 0x00, 0x56, 0xf4, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0xb1, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa6, 0x00, 0xc4, 0xff, 0xb5, 0x06, 0xca, 0xff, 0xfa, 0x59, 0x01, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x8c, 0xb1, 0xff, 0x2a, 0x00, 0x50, 0xac, 0xff, 0xa2, 0x99, 0xf9, 0xc4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x28, 0x47, 0xff, 0xff, 0x36, 0x3c, 0xff, 0xff, 0xde, 0x00, 0x66, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x39, 0x0c, 0xfa, 0xff, 0x64, 0x07, 0x0c, 0x00, 0x0c, 0x81, 0xc6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdc, 0x47, 0x00, 0x46, 0x7c, 0x3b, 0x00, 0xb1, 0xff, 0xff, 0x47, 0x25, 0xb4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xff, 0xa5, 0x00, 0x00, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0x59, 0x00, 0x00, 0x60, 0xff, 0xff, 0x00, 0x00, 0x6a, 0xff, 0xff, 0xe0, 0x56, 0x00, 0x07, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xd9, 0x01, 0x86, 0xc1, 0x5f, 0x00, 0x47, 0x40, 0x29, 0x06, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xda, 0x06, 0xf6, 0xff, 0x7a, 0xc9, 0xc4, 0x89, 0xe8, 0xaa, 0x00, 0x41, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x59, 0x0c, 0xd6, 0xa9, 0x10, 0x11, 0x4b, 0x28, 0x2a, 0x06, 0xd4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x00, 0x46, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x3c, 0xda, 0x00, 0x59, 0xd9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xa1, 0x00, 0x09, 0x8a, 0xff, 0xa6, 0x00, 0x4f, 0xda, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe8, 0x00, 0x00, 0xaa, 0xff, 0xff, 0xff, 0xa9, 0x00, 0x00, 0xe8, 0xf8, 0x92, 0x92, 0xe7, 0xff, 0xff, 0xff, 0x77, 0x00, 0x00, 0xea, 0xff, 0x00, 0x00, 0x6a, 0xff, 0xff, 0xff, 0xd6, 0x00, 0x00, 0xa1, 0xff, 0xff, 0xff, 0xff, 0xff, 0x28, 0x00, 0x0f, 0x20, 0x00, 0x60, 0x78, 0x89, 0x06, 0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5a, 0x46, 0xff, 0xff, 0x2c, 0x34, 0xba, 0x00, 0x37, 0xe4, 0x01, 0x7c, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9f, 0x00, 0x01, 0x24, 0x01, 0x1b, 0x69, 0x84, 0x54, 0x87, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb0, 0x00, 0x89, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x41, 0xff, 0x77, 0x01, 0x39, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9c, 0x00, 0x1a, 0xf6, 0x38, 0x3a, 0x00, 0x85, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x00, 0x00, 0x9a, 0xff, 0xff, 0xff, 0xa1, 0x00, 0x00, 0xf4, 0xd7, 0x00, 0x00, 0xb9, 0xff, 0xff, 0xff, 0x9f, 0x00, 0x00, 0xcc, 0xff, 0x00, 0x00, 0x6a, 0xff, 0xff, 0xff, 0xec, 0x00, 0x00, 0x99, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9f, 0xc7, 0xff, 0x9a, 0x00, 0xde, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x20, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb7, 0x00, 0x89, 0xff, 0xff, 0x41, 0x00, 0xf1, 0x07, 0x5c, 0xf9, 0x00, 0x90, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x69, 0xff, 0xff, 0x19, 0x60, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xd4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x56, 0x00, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x47, 0xff, 0xfa, 0x7c, 0x29, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x8f, 0x00, 0x57, 0x00, 0x85, 0xff, 0x56, 0x00, 0x9c, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x1e, 0x01, 0x77, 0xff, 0xff, 0xff, 0x76, 0x00, 0x1c, 0xff, 0xff, 0x07, 0x00, 0x86, 0xff, 0xff, 0xff, 0x96, 0x00, 0x00, 0xf7, 0xff, 0x00, 0x00, 0x6a, 0xff, 0xff, 0xff, 0xa4, 0x00, 0x00, 0xc7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb9, 0x00, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x39, 0x01, 0xd6, 0xff, 0xff, 0x26, 0x46, 0xff, 0x0f, 0x60, 0xf9, 0x00, 0xa1, 0xff, 0xff, 0xff, 0xb8, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x38, 0x47, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x82, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc6, 0x00, 0x76, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x46, 0xc4, 0xa9, 0x92, 0x78, 0x77, 0xb6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x82, 0x00, 0x7a, 0xec, 0x00, 0xba, 0xff, 0xfa, 0x66, 0x00, 0x44, 0xc4, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x76, 0x01, 0x00, 0x80, 0x81, 0x7c, 0x00, 0x00, 0x77, 0xff, 0xff, 0x5f, 0x00, 0x00, 0x7f, 0x95, 0x5f, 0x07, 0x00, 0x5a, 0xfa, 0xff, 0x00, 0x00, 0x37, 0x92, 0x88, 0x66, 0x00, 0x00, 0x29, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd4, 0x00, 0x69, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9c, 0x01, 0xde, 0xff, 0xff, 0xff, 0xff, 0x56, 0x00, 0x1f, 0xfa, 0xff, 0xca, 0x01, 0x88, 0xff, 0x0f, 0x65, 0xf9, 0x00, 0x9a, 0xff, 0xff, 0xff, 0x54, 0xbc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x54, 0x00, 0xca, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x2f, 0x2c, 0xff, 0xff, 0xff, 0xff, 0xff, 0x47, 0x28, 0xc1, 0x89, 0x8c, 0x6c, 0x54, 0x36, 0x0a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x99, 0xff, 0xff, 0xff, 0xe1, 0x4e, 0x25, 0xa6, 0xff, 0xe0, 0x00, 0xc8, 0xe7, 0x6f, 0xa9, 0x7a, 0x00, 0x00, 0x2a, 0xc7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x3f, 0x00, 0x01, 0x01, 0x00, 0x00, 0x3f, 0xf6, 0xff, 0xff, 0xeb, 0x36, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0xf0, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x25, 0xc8, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x38, 0x00, 0x48, 0x9c, 0xb8, 0x94, 0xa3, 0x70, 0x07, 0x00, 0x6f, 0xff, 0xff, 0xff, 0xff, 0x91, 0x01, 0x64, 0xff, 0xff, 0x4a, 0x11, 0xf1, 0xec, 0x00, 0x71, 0xff, 0x21, 0x41, 0xb8, 0xba, 0x65, 0x00, 0x87, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xaa, 0x01, 0x17, 0x77, 0xb5, 0xb9, 0xb5, 0x95, 0x3b, 0x00, 0x00, 0xea, 0xff, 0xff, 0xff, 0x7c, 0x1c, 0xd6, 0xf0, 0x50, 0x06, 0x29, 0x58, 0x7a, 0x98, 0xa7, 0xb7, 0xc6, 0xd6, 0xdc, 0xd6, 0xcf, 0xca, 0xeb, 0xff, 0xff, 0x77, 0x06, 0xa5, 0xfa, 0xff, 0xff, 0xbc, 0x00, 0x11, 0x00, 0x96, 0xff, 0xff, 0x91, 0x00, 0x00, 0x00, 0x0c, 0x3e, 0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x91, 0x64, 0x3a, 0x65, 0x90, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x8c, 0x65, 0x3f, 0x65, 0x89, 0xff, 0xff, 0xff, 0xff, 0x56, 0x56, 0x59, 0x68, 0x6f, 0x89, 0xa7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd6, 0x49, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x46, 0xc8, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6c, 0x9a, 0xff, 0x5f, 0x19, 0xbf, 0xff, 0xff, 0x22, 0xa9, 0xff, 0x99, 0x00, 0x00, 0x00, 0x00, 0x01, 0x5c, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x84, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x17, 0x7c, 0xff, 0xff, 0xff, 0xb4, 0x4b, 0xe8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0x65, 0x00, 0x00, 0xa3, 0xff, 0xff, 0xff, 0xff, 0xcf, 0x8f, 0x97, 0xb4, 0xd6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xc1, 0xa7, 0x90, 0x90, 0x9f, 0xb2, 0xf1, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x31, 0xa2, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xd6, 0x9c, 0x89, 0x96, 0xd8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xb5, 0x9c, 0x89, 0x98, 0xa6, 0xd1, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb5, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x41, 0x00, 0xa9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x9a, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
};


void ST77XX_DrawLogo(uint16_t x, uint16_t y)
{
    if ((x >= ST77XX_WIDTH) || (y >= ST77XX_HEIGHT))
        return;

    ST77XX_SetAddrWindow(x, y, x + __LOGO_WIDTH - 1, y + __LOGO_HEIGHT - 1);
    for (int i = 0; i < __LOGO_HEIGHT * __LOGO_WIDTH; i++)
    {
        uint8_t c = LOGO[i];
        uint16_t rb = (uint16_t) 0b11111 * c / (uint16_t) 0xff;
        uint16_t g = (uint16_t) 0b111111 * c / (uint16_t) 0xff;
        ST77XX_TransmitByte(((rb << 3) | (g >> 3)) & 0xff);
        ST77XX_TransmitByte((rb | (g << (8 - 3))) & 0xff);
    }
}
